%ODE-solver options
solver = 'ode45';

%ODE-solver options
%Type 'help odeset' in the Matlab window for more details
inopts = odeset('RelTol',1e-10,'AbsTol',1e-10,'MaxStep',0.1);

% Name of the file with the two vectorfields
vfields = 'vectorfields2s';

% Name of the file with the jacobians
jacobians = '';

% Name of the file with the action at the Poincare section 
pfunction = '';


% Filippov parameter
C = [1,1];

% Internal parameters
w1 = 3.1799;
w2 = 0.0393;
r = 5;

% Systems parameters
km     = 3.5693;
ktheta = 0.078;
Ju     = 0.4765;
Jl     = 0.0326;
beta1  = 2*w1;
beta2  = 2*w2;
bup    = 1.9667;
bun    = bup;
bl     = 0.0042;
Tsup   = 0.3216;
Tsun   = 0.3026;

Tsl    = 0.0940;
T1     = 0.0826;
T2     = -0.2910;
u      = r;

params = [km,ktheta,Ju,Jl,beta1,beta2,bup,bun,bl,Tsup,Tsun,Tsl,T1,T2,u];

% Initial condition
y0 = 20*rand(1,3)-10;

% Integration time
T =100;
tspan = [0,T];


% Output is the time, states and events as in Matlab's standard output
[t,y,te,ye,ie,se] = filippov2s(vfields,jacobians,pfunction,solver,tspan,y0,params,C,inopts);

figure(2),hold on
plot(t,y(:,1),'b',t,y(:,2),'k',t,y(:,3),'r')
xlabel('t'),ylabel('x_1 (blue), x_2 (black), x_3 (red)')
grid on
