% ODE solver
solver = 'ode45';

%ODE-solver options
%Type 'help odeset' in the Matlab window for more details
opts = odeset('RelTol',1e-6,'AbsTol',1e-6,'MaxStep',0.01);

% Name of the file with the two vectorfields
vfields = 'vectorfields';

% Name of the file with the two Jacobianss
jacobians = 'jacobians';

% Name of the file with the two Jacobianss
pfunction = 'pfunction';

% Filippov parameter
C = 1;

% Parameters
F = 0.4; omega = 1/3;
params = [F,omega];

% Initial condition
y0 = [1,2,0];

% Integration time
T = 2*pi/omega*10;
tspan = [0,T];

% Output is the time, states and events as in Matlab's standard output
[t,y,te,ye,ie,se] = filippov(vfields,jacobians,pfunction,solver,tspan,y0,params,C,opts);

% Plots of the different state variables
figure(1)
plot(t,y(:,1),'b')
title('A plot of x_1 versus time t.')
xlabel('time (t)'), ylabel('x_1')

figure(2)
plot(t,y(:,2),'b')
title('A plot of x_2 versus time t.')
xlabel('time'), ylabel('x_2')

figure(3)
plot(y(:,1),y(:,2),'b')
title('A phase plot of x_2 versus x_1.')
xlabel('x_1'), ylabel('x_2')

figure(4)
plot(y(:,3),y(:,2),'b')
title('A plot of x_2 versus the scaled time t.')
xlabel('scaled time (x_3)'), ylabel('x_2')